/*
Example for UT_7_SEG Click

    Date          : Jun 2017.
    Author        : Danilo M.

Test configuration CEC :
    
    MCU             : CEC1702
    Dev. Board      : Clicker 2 for CEC1702
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This example shows countdown from 99 to 00, the LED driver Max6969 is programmed via SPI,
    and the brightness of 7 seg display is regulated by duty cycle of PWM.

*/

#include "stdint.h"

sbit   MAX6969_LE_PIN   at  GPIO_OUTPUT_000_007.B3;

uint16_t pwmPeriod;
static const uint8_t minus_char = 0x40;

void systemInit()
{
   GPIO_Digital_Output( &GPIO_PORT_000_007, _GPIO_PINMASK_3 );
    SPI0_Init_Advanced( 4000000,  _SPI_MSB_FIRST,
                        _SPI_CLK_IDLE_LOW | _SPI_SAMPLE_DATA_RISING_EDGE );
    pwmPeriod = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();

}

void MAX6969_Chip_Select()
{
    MAX6969_LE_PIN = 1;
    asm nop
    asm nop
    asm nop
    MAX6969_LE_PIN = 0;
}

static void U7SEG_Write(uint8_t number)
{
    char numbers[10] = {0x3F, 0x06, 0x5B, 0x4F, 0x66, 0x6D, 0x7D, 0x07, 0x7F, 0x6F};
    uint8_t tens = number / 10;
    uint8_t ones = number % 10;
    if (number > 99) return;

    SPI_Wr_Ptr(numbers[ones]);
    SPI_Wr_Ptr(numbers[tens]);
}

void main()
{
    uint8_t counter;

    systemInit();
    counter = 100;

    while(counter--)
    {
        U7SEG_Write(counter);
        MAX6969_Chip_Select();
        Delay_ms(500);
    }

    SPI_Wr_Ptr(minus_char);
    SPI_Wr_Ptr(minus_char);
    MAX6969_Chip_Select();
}