/*
Example for UT_7_SEG Click

    Date          : Jun 2017.
    Author        : Danilo M.

Test configuration MSP :
    
    MCU             : MSP432
    Dev. Board      : Clicker 2 for MSP432
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This example shows countdown from 99 to 00, the LED driver Max6969 is programmed via SPI,
    and the brightness of 7 seg display is regulated by duty cycle of PWM.

*/

#include "stdint.h"

sbit   MAX6969_LE_PIN   at  DIO_P5OUT.B0;
sbit   CSL at DIO_P2OUT.B7 ;
uint16_t pwmPeriod;
static const uint8_t minus_char = 0x40;

void systemInit()
{
    GPIO_Digital_Output( &DIO_P5OUT, _GPIO_PINMASK_0 );
    GPIO_Digital_Output( &DIO_P2OUT, _GPIO_PINMASK_7 );
    CSL = 1;
    SPI5_Init_Advanced( _SPI_MASTER, 2, _SPI_CLOCKSOURCE_SMCLK, _SPI_MSB_FIRST,
                        _SPI_PHASE_DATA_CHANGE_FIRST_CAPTURE_NEXT,
                        _SPI_CLK_IDLE_HIGH, _SPI_3PIN ,
                        &_GPIO_MODULE_SPIB0_A576 );
    pwmPeriod = PWM0_Init(25000, _PWM_CFG_CLOCK_SRC_SMCLK | _PWM_CFG_OUTPUTMODE_SET | _PWM_CFG_CHANNEL_4, &_GPIO_MODULE_PWM_TA0_4_A15);
    PWM0_SetDuty(pwmPeriod/2, _PWM_CFG_CHANNEL_4);
    PWM0_Start();


}

void MAX6969_Chip_Select()
{
    MAX6969_LE_PIN = 1;
    asm nop
    asm nop
    asm nop
    MAX6969_LE_PIN = 0;
}

static void U7SEG_Write(uint8_t number)
{
    char numbers[10] = {0x3F, 0x06, 0x5B, 0x4F, 0x66, 0x6D, 0x7D, 0x07, 0x7F, 0x6F};
    uint8_t tens = number / 10;
    uint8_t ones = number % 10;
    if (number > 99) return;

    SPI_Wr_Ptr(numbers[ones]);
    SPI_Wr_Ptr(numbers[tens]);
}

void main()
{
    uint8_t counter;

    systemInit();
    counter = 100;

    while(counter--)
    {
        U7SEG_Write(counter);
        MAX6969_Chip_Select();
        Delay_ms(500);
    }

    SPI_Wr_Ptr(minus_char);
    SPI_Wr_Ptr(minus_char);
    MAX6969_Chip_Select();
}